'use strict';

Object.defineProperty(exports, '__esModule', {
  value: true
});
exports['default'] = LaunchControlXL;

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { 'default': obj }; }

var _genericMidiController = require('generic-midi-controller');

var _genericMidiController2 = _interopRequireDefault(_genericMidiController);

function LaunchControlXL() {
  var controller = (0, _genericMidiController2['default'])(inputs(), outputs());

  controller.reset = reset;

  return controller;

  function reset() {
    controller.send([176, 0, 0]);
  }

  function inputs() {
    var buttons = [];
    var faders = [];
    var knobs = [];

    for (var j = 0; j < 4; j++) {
      for (var i = 41; i <= 44; i++) {
        buttons.push(map(i + j * 16));
      }
    }

    for (var i = 77; i <= 84; i++) {
      faders.push(smooth(i));
    }

    for (var i = 13; i <= 20; i++) {
      knobs.push(smooth(i));
    }
    for (var i = 29; i <= 36; i++) {
      knobs.push(smooth(i));
    }
    for (var i = 49; i <= 56; i++) {
      knobs.push(smooth(i));
    }

    return {
      buttons: buttons,
      faders: faders,
      knobs: knobs
    };

    function map(id) {
      return function (msg) {
        if (msg[1] !== id) return;
        if (msg[0] !== 152 && msg[0] !== 136) return;
        return msg[2];
      };
    }

    function smooth(id) {
      return function (msg) {
        if (msg[1] !== id) return;
        if (msg[0] !== 184) return;
        return msg[2];
      };
    }
  }

  function outputs() {
    var buttons = [];
    var knobs = [];

    for (var i = 41; i <= 92; i++) {
      buttons.push(btn(i));
    }

    for (var i = 0; i <= 23; i++) {
      knobs.push(knob(i));
    }

    return {
      buttons: buttons,
      knobs: knobs
    };

    function btn(id) {
      return function (value, send) {
        return send([152, id, value]);
      };
    }

    function knob(id) {
      return function (value, send) {
        return send([240, 0, 32, 41, 2, 17, 120, 8, id, value, 247]);
      };
    }
  }
}

module.exports = exports['default'];
